package ValveExample2
  model WaterValveTest1
    replaceable package Medium = Modelica.Media.Water.StandardWater;
    ValveExample2.ValveWater1 waterValve1(redeclare package Medium = Medium, Av = 3.68008e-5, CvData = Modelica.Fluid.Types.CvTypes.Av, dp_nominal = 100000, m_flow_nominal = 0.03) annotation(
      Placement(visible = true, transformation(origin = {2, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary(redeclare package Medium = Medium, T = 293.15, nPorts = 2, p = 201325) annotation(
      Placement(visible = true, transformation(origin = {-80, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary1(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 101325) annotation(
      Placement(visible = true, transformation(origin = {58, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Ramp ramp1(duration = 10, height = 569.99, offset = 0.0, startTime = 0) annotation(
      Placement(visible = true, transformation(origin = {-72, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    inner Modelica.Fluid.System system annotation(
      Placement(visible = true, transformation(origin = {62, 38}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    ValveWater2 waterValve2(redeclare package Medium = Medium, Av = 3.68008e-5, CvData = Modelica.Fluid.Types.CvTypes.Av, dp_nominal = 100000, m_flow_nominal = 0.03) annotation(
      Placement(visible = true, transformation(origin = {2, -52}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary2(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 101325) annotation(
      Placement(visible = true, transformation(origin = {58, -52}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Gain gain(k = 1 / 570) annotation(
      Placement(visible = true, transformation(origin = {-38, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(boundary.ports[2], waterValve2.port_a) annotation(
      Line(points = {{-70, 0}, {-50, 0}, {-50, -52}, {-8, -52}}, color = {0, 127, 255}));
    connect(boundary.ports[1], waterValve1.port_a) annotation(
      Line(points = {{-70, 0}, {-8, 0}}, color = {0, 127, 255}));
    connect(waterValve2.port_b, boundary2.ports[1]) annotation(
      Line(points = {{12, -52}, {48, -52}, {48, -52}, {48, -52}}, color = {0, 127, 255}));
    connect(waterValve1.port_b, boundary1.ports[1]) annotation(
      Line(points = {{12, 0}, {48, 0}}, color = {0, 127, 255}));
    connect(ramp1.y, gain.u) annotation(
      Line(points = {{-60, 46}, {-52, 46}, {-52, 46}, {-50, 46}}, color = {0, 0, 127}));
    connect(gain.y, waterValve1.opening) annotation(
      Line(points = {{-26, 46}, {2, 46}, {2, 8}, {0, 8}}, color = {0, 0, 127}));
    connect(gain.y, waterValve2.opening) annotation(
      Line(points = {{-26, 46}, {-20, 46}, {-20, -28}, {2, -28}, {2, -44}, {2, -44}}, color = {0, 0, 127}));
    annotation(
      experiment(StartTime = 0, StopTime = 10, Tolerance = 1e-06, Interval = 0.02));
  end WaterValveTest1;

  model ValveWater1 "Valve for (almost) incompressible fluids"
    extends Modelica.Fluid.Valves.BaseClasses.PartialValve;
    import Modelica.Fluid.Types.CvTypes;
    import Modelica.Constants.pi;
    import Modelica.Fluid.Utilities;
    import SI = Modelica.SIunits;
    constant SI.ReynoldsNumber Re_turbulent = 4000 "cf. straight pipe for fully open valve -- dp_turbulent increases for closing valve";
    parameter Boolean use_Re = system.use_eps_Re "= true, if turbulent region is defined by Re, otherwise by m_flow_small" annotation(
      Dialog(tab = "Advanced"),
      Evaluate = true);
    //SI.MassFlowRate m_flow_turbulent=if not use_Re then m_flow_small else
    //  max(m_flow_small,
    //      (Modelica.Constants.pi/8)*sqrt(max(relativeFlowCoefficient,0.001)*Av*4/pi)*(Medium.dynamicViscosity(state_a) + Medium.dynamicViscosity(state_b))*Re_turbulent);
    //SI.AbsolutePressure dp_turbulent_=if not use_Re then dp_small else
    //  max(dp_small, m_flow_turbulent^2/(max(relativeFlowCoefficient,0.001)^2*Av^2*(Medium.density(state_a) + Medium.density(state_b))/2));
    // substitute m_flow_turbulent into dp_turbulent
    SI.AbsolutePressure dp_turbulent = if not use_Re then dp_small else max(dp_small, (Medium.dynamicViscosity(state_a) + Medium.dynamicViscosity(state_b)) ^ 2 * pi / 8 * Re_turbulent ^ 2 / (max(relativeFlowCoefficient, 0.001) * Av * (Medium.density(state_a) + Medium.density(state_b))));
    Modelica.Blocks.Tables.CombiTable1D combiTable1D1(smoothness = Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table = [0, 0; 0.052631579, 0.271493213; 0.157894737, 0.542986425; 0.210526316, 0.601809955; 0.263157895, 0.633484163; 0.368421053, 0.791855204; 0.473684211, 0.882352941; 0.631578947, 0.972850679; 0.789473684, 0.995475113; 1, 1]) annotation(
      Placement(visible = true, transformation(origin = {106, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  protected
    Real relativeFlowCoefficient;
  initial equation
    if CvData == CvTypes.OpPoint then
      m_flow_nominal = valveCharacteristic(opening_nominal) * Av * sqrt(rho_nominal) * Utilities.regRoot(dp_nominal, dp_small) "Determination of Av by the operating point";
    end if;
  equation
    connect(opening_actual, combiTable1D1.u[1]) annotation(
      Line(points = {{70, 20}, {92, 20}, {92, 20}, {94, 20}}, color = {0, 0, 127}));
// m_flow = valveCharacteristic(opening)*Av*sqrt(d)*sqrt(dp);
// relativeFlowCoefficient = valveCharacteristic(opening_actual);
    relativeFlowCoefficient = combiTable1D1.y[1];
    if checkValve then
      m_flow = homotopy(relativeFlowCoefficient * Av * sqrt(Medium.density(state_a)) * Utilities.regRoot2(dp, dp_turbulent, 1.0, 0.0, use_yd0 = true, yd0 = 0.0), relativeFlowCoefficient * m_flow_nominal * dp / dp_nominal);
/* In Modelica 3.1 (Disadvantage: Unnecessary event at dp=0, and instead of smooth=2)
    m_flow = valveCharacteristic(opening)*Av*sqrt(Medium.density(state_a))*
                  (if dp>=0 then Utilities.regRoot(dp, dp_turbulent) else 0);
    */
    elseif not allowFlowReversal then
      m_flow = homotopy(relativeFlowCoefficient * Av * sqrt(Medium.density(state_a)) * Utilities.regRoot(dp, dp_turbulent), relativeFlowCoefficient * m_flow_nominal * dp / dp_nominal);
    else
      m_flow = homotopy(relativeFlowCoefficient * Av * Utilities.regRoot2(dp, dp_turbulent, Medium.density(state_a), Medium.density(state_b)), relativeFlowCoefficient * m_flow_nominal * dp / dp_nominal);
/* In Modelica 3.1 (Disadvantage: Unnecessary event at dp=0, and instead of smooth=2)
    m_flow = smooth(0, Utilities.regRoot(dp, dp_turbulent)*(if dp>=0 then sqrt(Medium.density(state_a)) else sqrt(Medium.density(state_b))));
    */
    end if;
    annotation(
      Documentation(info = "<html>
<p>
Valve model according to the IEC 534/ISA S.75 standards for valve sizing, incompressible fluids.</p>

<p>
The parameters of this model are explained in detail in
<a href=\"modelica://Modelica.Fluid.Valves.BaseClasses.PartialValve\">PartialValve</a>
(the base model for valves).
</p>

<p>
This model assumes that the fluid has a low compressibility, which is always the case for liquids.
It can also be used with gases, provided that the pressure drop is lower than 0.2 times the absolute pressure at the inlet, so that the fluid density does not change much inside the valve.</p>

<p>
If <code>checkValve</code> is false, the valve supports reverse flow, with a symmetric flow characteristic curve. Otherwise, reverse flow is stopped (check valve behaviour).
</p>

<p>
The treatment of parameters <strong>Kv</strong> and <strong>Cv</strong> is
explained in detail in the
<a href=\"modelica://Modelica.Fluid.UsersGuide.ComponentDefinition.ValveCharacteristics\">User's Guide</a>.
</p>

</html>", revisions = "<html>
<ul>
<li><em>2 Nov 2005</em>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Adapted from the ThermoPower library.</li>
</ul>
</html>"),
      Diagram(coordinateSystem(extent = {{-100, -100}, {120, 100}})),
      Icon(coordinateSystem(extent = {{-100, -100}, {120, 100}})));
  end ValveWater1;

  model ValveWater2 "Valve for (almost) incompressible fluids"
    extends Modelica.Fluid.Valves.BaseClasses.PartialValve;
    import Modelica.Fluid.Types.CvTypes;
    import Modelica.Constants.pi;
    import Modelica.Fluid.Utilities;
    import SI = Modelica.SIunits;
    constant SI.ReynoldsNumber Re_turbulent = 4000 "cf. straight pipe for fully open valve -- dp_turbulent increases for closing valve";
    parameter Boolean use_Re = system.use_eps_Re "= true, if turbulent region is defined by Re, otherwise by m_flow_small" annotation(
      Dialog(tab = "Advanced"),
      Evaluate = true);
    //SI.MassFlowRate m_flow_turbulent=if not use_Re then m_flow_small else
    //  max(m_flow_small,
    //      (Modelica.Constants.pi/8)*sqrt(max(relativeFlowCoefficient,0.001)*Av*4/pi)*(Medium.dynamicViscosity(state_a) + Medium.dynamicViscosity(state_b))*Re_turbulent);
    //SI.AbsolutePressure dp_turbulent_=if not use_Re then dp_small else
    //  max(dp_small, m_flow_turbulent^2/(max(relativeFlowCoefficient,0.001)^2*Av^2*(Medium.density(state_a) + Medium.density(state_b))/2));
    // substitute m_flow_turbulent into dp_turbulent
    SI.AbsolutePressure dp_turbulent = if not use_Re then dp_small else max(dp_small, (Medium.dynamicViscosity(state_a) + Medium.dynamicViscosity(state_b)) ^ 2 * pi / 8 * Re_turbulent ^ 2 / (max(relativeFlowCoefficient, 0.001) * Av * (Medium.density(state_a) + Medium.density(state_b))));
    Modelica.Blocks.Tables.CombiTable1D combiTable1D1(smoothness = Modelica.Blocks.Types.Smoothness.ContinuousDerivative, table = [0, 0; 0.052631579, 0.126696833; 0.157894737, 0.244343891; 0.210526316, 0.271493213; 0.263157895, 0.330316742; 0.368421053, 0.65158371; 0.473684211, 0.800904977; 0.631578947, 0.914027149; 0.789473684, 0.968325792; 1, 1]) annotation(
      Placement(visible = true, transformation(origin = {106, 20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  protected
    Real relativeFlowCoefficient;
  initial equation
    if CvData == CvTypes.OpPoint then
      m_flow_nominal = valveCharacteristic(opening_nominal) * Av * sqrt(rho_nominal) * Utilities.regRoot(dp_nominal, dp_small) "Determination of Av by the operating point";
    end if;
  equation
    connect(opening_actual, combiTable1D1.u[1]) annotation(
      Line(points = {{70, 20}, {92, 20}, {92, 20}, {94, 20}}, color = {0, 0, 127}));
// m_flow = valveCharacteristic(opening)*Av*sqrt(d)*sqrt(dp);
// relativeFlowCoefficient = valveCharacteristic(opening_actual);
    relativeFlowCoefficient = combiTable1D1.y[1];
    if checkValve then
      m_flow = homotopy(relativeFlowCoefficient * Av * sqrt(Medium.density(state_a)) * Utilities.regRoot2(dp, dp_turbulent, 1.0, 0.0, use_yd0 = true, yd0 = 0.0), relativeFlowCoefficient * m_flow_nominal * dp / dp_nominal);
/* In Modelica 3.1 (Disadvantage: Unnecessary event at dp=0, and instead of smooth=2)
    m_flow = valveCharacteristic(opening)*Av*sqrt(Medium.density(state_a))*
                  (if dp>=0 then Utilities.regRoot(dp, dp_turbulent) else 0);
    */
    elseif not allowFlowReversal then
      m_flow = homotopy(relativeFlowCoefficient * Av * sqrt(Medium.density(state_a)) * Utilities.regRoot(dp, dp_turbulent), relativeFlowCoefficient * m_flow_nominal * dp / dp_nominal);
    else
      m_flow = homotopy(relativeFlowCoefficient * Av * Utilities.regRoot2(dp, dp_turbulent, Medium.density(state_a), Medium.density(state_b)), relativeFlowCoefficient * m_flow_nominal * dp / dp_nominal);
/* In Modelica 3.1 (Disadvantage: Unnecessary event at dp=0, and instead of smooth=2)
    m_flow = smooth(0, Utilities.regRoot(dp, dp_turbulent)*(if dp>=0 then sqrt(Medium.density(state_a)) else sqrt(Medium.density(state_b))));
    */
    end if;
    annotation(
      Documentation(info = "<html>
<p>
Valve model according to the IEC 534/ISA S.75 standards for valve sizing, incompressible fluids.</p>

<p>
The parameters of this model are explained in detail in
<a href=\"modelica://Modelica.Fluid.Valves.BaseClasses.PartialValve\">PartialValve</a>
(the base model for valves).
</p>

<p>
This model assumes that the fluid has a low compressibility, which is always the case for liquids.
It can also be used with gases, provided that the pressure drop is lower than 0.2 times the absolute pressure at the inlet, so that the fluid density does not change much inside the valve.</p>

<p>
If <code>checkValve</code> is false, the valve supports reverse flow, with a symmetric flow characteristic curve. Otherwise, reverse flow is stopped (check valve behaviour).
</p>

<p>
The treatment of parameters <strong>Kv</strong> and <strong>Cv</strong> is
explained in detail in the
<a href=\"modelica://Modelica.Fluid.UsersGuide.ComponentDefinition.ValveCharacteristics\">User's Guide</a>.
</p>

</html>", revisions = "<html>
<ul>
<li><em>2 Nov 2005</em>
    by <a href=\"mailto:francesco.casella@polimi.it\">Francesco Casella</a>:<br>
       Adapted from the ThermoPower library.</li>
</ul>
</html>"));
  end ValveWater2;

  model ButterflyValveTest1
    replaceable package Medium = Modelica.Media.Water.StandardWater;
    Modelica.Fluid.Valves.ValveVaporizing butterflyValve(redeclare package Medium = Medium, redeclare function valveCharacteristic = Modelica.Fluid.Valves.BaseClasses.ValveCharacteristics.equalPercentage(rangeability = 15.38461538, delta = 0.37), redeclare function FlCharacteristic = fl_butterfly, Cv = 790, CvData = Modelica.Fluid.Types.CvTypes.Cv, Fl_nominal = 0.8843, dp_nominal = 18000, m_flow_nominal = 80) annotation(
      Placement(visible = true, transformation(origin = {-2, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 119231.849) annotation(
      Placement(visible = true, transformation(origin = {-56, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary1(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 101325) annotation(
      Placement(visible = true, transformation(origin = {52, 8}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Ramp ramp1(duration = 10, height = 69.9, offset = 0, startTime = 0) annotation(
      Placement(visible = true, transformation(origin = {-70, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    inner Modelica.Fluid.System system annotation(
      Placement(visible = true, transformation(origin = {52, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Gain gain(k = 1 / 70) annotation(
      Placement(visible = true, transformation(origin = {-26, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(butterflyValve.port_b, boundary1.ports[1]) annotation(
      Line(points = {{8, 8}, {42, 8}}, color = {0, 127, 255}));
    connect(boundary.ports[1], butterflyValve.port_a) annotation(
      Line(points = {{-46, 8}, {-12, 8}, {-12, 8}, {-12, 8}}, color = {0, 127, 255}));
    connect(gain.y, butterflyValve.opening) annotation(
      Line(points = {{-14, 46}, {-2, 46}, {-2, 16}, {-2, 16}}, color = {0, 0, 127}));
    connect(ramp1.y, gain.u) annotation(
      Line(points = {{-58, 46}, {-38, 46}, {-38, 46}, {-38, 46}}, color = {0, 0, 127}));
    annotation(
      experiment(StartTime = 0, StopTime = 10, Tolerance = 1e-6, Interval = 0.02));
  end ButterflyValveTest1;

  function fl_butterfly
    extends Modelica.Fluid.Valves.BaseClasses.ValveCharacteristics.baseFun;
  algorithm
    rc := (0.1187 * pos - 0.3270) * pos + 1.0;
  end fl_butterfly;

  model NeedleValveTest1
    replaceable package Medium = Modelica.Media.Water.StandardWater;
    Modelica.Fluid.Valves.ValveIncompressible needleValve(redeclare package Medium = Medium, Cv = 0.0045, CvData = Modelica.Fluid.Types.CvTypes.Cv, dp_nominal = 5.10132e+06, m_flow_nominal = 7.63e-3) annotation(
      Placement(visible = true, transformation(origin = {2, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 5101325) annotation(
      Placement(visible = true, transformation(origin = {-46, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary1(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 101325) annotation(
      Placement(visible = true, transformation(origin = {48, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Ramp ramp1(duration = 10, height = 11, offset = 0, startTime = 0) annotation(
      Placement(visible = true, transformation(origin = {-54, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Gain gain1(k = 1 / 11) annotation(
      Placement(visible = true, transformation(origin = {-12, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    inner Modelica.Fluid.System system annotation(
      Placement(visible = true, transformation(origin = {50, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(gain1.y, needleValve.opening) annotation(
      Line(points = {{0, 44}, {2, 44}, {2, 8}, {2, 8}}, color = {0, 0, 127}));
    connect(ramp1.y, gain1.u) annotation(
      Line(points = {{-42, 44}, {-24, 44}}, color = {0, 0, 127}));
    connect(boundary1.ports[1], needleValve.port_b) annotation(
      Line(points = {{38, 0}, {12, 0}, {12, 0}, {12, 0}}, color = {0, 127, 255}));
    connect(boundary.ports[1], needleValve.port_a) annotation(
      Line(points = {{-36, 0}, {-8, 0}}, color = {0, 127, 255}));
  connect(ramp1.y, gain1.u) annotation(
      Line(points = {{-42, 44}, {-24, 44}, {-24, 44}, {-24, 44}}, color = {0, 0, 127}));
    annotation(
      experiment(StartTime = 0, StopTime = 10, Tolerance = 1e-6, Interval = 0.02));
  end NeedleValveTest1;

  model ButterflyValveTest2
    replaceable package Medium = Modelica.Media.Water.StandardWater;
    Modelica.Fluid.Valves.ValveVaporizing butterflyValve(redeclare package Medium = Medium, redeclare function valveCharacteristic = Modelica.Fluid.Valves.BaseClasses.ValveCharacteristics.equalPercentage(rangeability = 15.38461538, delta = 0.37), redeclare function FlCharacteristic = fl_butterfly, Cv = 790, CvData = Modelica.Fluid.Types.CvTypes.Cv, Fl_nominal = 0.8843, dp_nominal = 18000, m_flow_nominal = 80) annotation(
      Placement(visible = true, transformation(origin = {-2, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 119231.849) annotation(
      Placement(visible = true, transformation(origin = {-56, 8}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary1(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 101325, use_p_in = true) annotation(
      Placement(visible = true, transformation(origin = {52, 8}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    inner Modelica.Fluid.System system annotation(
      Placement(visible = true, transformation(origin = {52, 60}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Gain gain(k = 1 / 70) annotation(
      Placement(visible = true, transformation(origin = {-26, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Constant const(k = 35) annotation(
      Placement(visible = true, transformation(origin = {-68, 46}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.Ramp ramp(duration = 10, height = -110000, offset = 119000) annotation(
      Placement(visible = true, transformation(origin = {96, 16}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Modelica.Blocks.Sources.RealExpression realExpression(y = sqrt(butterflyValve.dp)) annotation(
      Placement(visible = true, transformation(origin = {-2, -26}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(butterflyValve.port_b, boundary1.ports[1]) annotation(
      Line(points = {{8, 8}, {42, 8}}, color = {0, 127, 255}));
    connect(boundary.ports[1], butterflyValve.port_a) annotation(
      Line(points = {{-46, 8}, {-12, 8}, {-12, 8}, {-12, 8}}, color = {0, 127, 255}));
    connect(gain.y, butterflyValve.opening) annotation(
      Line(points = {{-14, 46}, {-2, 46}, {-2, 16}, {-2, 16}}, color = {0, 0, 127}));
    connect(const.y, gain.u) annotation(
      Line(points = {{-56, 46}, {-40, 46}, {-40, 46}, {-38, 46}}, color = {0, 0, 127}));
    connect(ramp.y, boundary1.p_in) annotation(
      Line(points = {{85, 16}, {64, 16}}, color = {0, 0, 127}));
    annotation(
      experiment(StartTime = 0, StopTime = 10, Tolerance = 1e-6, Interval = 0.02),
      Diagram(coordinateSystem(extent = {{-100, -100}, {120, 100}})),
      Icon(coordinateSystem(extent = {{-100, -100}, {120, 100}})));
  end ButterflyValveTest2;
  
  model NeedleValveTest2
    replaceable package Medium = Modelica.Media.Water.StandardWater;
    Modelica.Fluid.Valves.ValveIncompressible needleValve(redeclare package Medium = Medium, Cv = 0.0045, CvData = Modelica.Fluid.Types.CvTypes.Cv, dp_nominal = 5.10132e+06, m_flow_nominal = 7.63e-3) annotation(
      Placement(visible = true, transformation(origin = {2, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary(redeclare package Medium = Medium, T = 293.15, nPorts = 1, p = 5101325) annotation(
      Placement(visible = true, transformation(origin = {-46, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    Modelica.Fluid.Sources.Boundary_pT boundary1(redeclare package Medium = Medium, T = 293.15, nPorts = 1, use_p_in = true) annotation(
      Placement(visible = true, transformation(origin = {48, 0}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
    Modelica.Blocks.Math.Gain gain1(k = 1 / 11) annotation(
      Placement(visible = true, transformation(origin = {-12, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
    inner Modelica.Fluid.System system annotation(
      Placement(visible = true, transformation(origin = {50, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Constant const(k = 5)  annotation(
      Placement(visible = true, transformation(origin = {-56, 44}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.Ramp ramp(duration = 10, height = -5000000, offset = 5101325)  annotation(
      Placement(visible = true, transformation(origin = {82, 8}, extent = {{10, -10}, {-10, 10}}, rotation = 0)));
  Modelica.Blocks.Sources.RealExpression realExpression(y = sqrt(needleValve.dp))  annotation(
      Placement(visible = true, transformation(origin = {2, -32}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  equation
    connect(gain1.y, needleValve.opening) annotation(
      Line(points = {{0, 44}, {2, 44}, {2, 8}, {2, 8}}, color = {0, 0, 127}));
    connect(boundary1.ports[1], needleValve.port_b) annotation(
      Line(points = {{38, 0}, {12, 0}, {12, 0}, {12, 0}}, color = {0, 127, 255}));
    connect(boundary.ports[1], needleValve.port_a) annotation(
      Line(points = {{-36, 0}, {-8, 0}}, color = {0, 127, 255}));
  connect(const.y, gain1.u) annotation(
      Line(points = {{-44, 44}, {-24, 44}, {-24, 44}, {-24, 44}}, color = {0, 0, 127}));
  connect(ramp.y, boundary1.p_in) annotation(
      Line(points = {{71, 8}, {60, 8}}, color = {0, 0, 127}));
    annotation(
      experiment(StartTime = 0, StopTime = 10, Tolerance = 1e-6, Interval = 0.02));
  end NeedleValveTest2;
  annotation(
    uses(Modelica(version = "3.2.3")));
end ValveExample2;